# CseIdentity

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email_address** | **str** | The email address for the sending identity. The email address must be the primary email address of the authenticated user. | [optional] 
**primary_key_pair_id** | **str** | If a key pair is associated, the identifier of the key pair, CseKeyPair. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

